import gtk
import gobject

class LeftAlignedLabel(gtk.Label):
	def __init__(self,str=None):
		gtk.Label.__init__(self,str)
		self.set_line_wrap(True)
		self.set_alignment(0,0)
		self.set_selectable(True)

class TitleLabel(LeftAlignedLabel):

	def __make_markup(self,str):
		return "<span weight='bold' size='larger'>%s</span>"%str
	
	def __init__(self,str=None):
		LeftAlignedLabel.__init__(self,str)
		if str: self.set_text(self.__make_markup(str))
	
	def set_text(self,str):
		self.text = str
		gtk.Label.set_markup(self,self.__make_markup(str))
		
	def get_text(self,str):
		return self.text
	
	def set_markup(self,str):
		self.set_text(str)

class Alert(gtk.Dialog):
	
	def __init__(self,parent_window,primary_text,secondary_text=None,buttons=None,flags=0,stock_icon_id=gtk.STOCK_DIALOG_QUESTION):
		gtk.Dialog.__init__(self,"",parent_window,flags,buttons=None)
		if buttons:
			for idortext,responseid in buttons: self.add_button(idortext,responseid)
		
		self.set_resizable(False)
		self.set_property("skip_pager_hint",True)
		self.set_property("skip_taskbar_hint",True)
		self.set_border_width(6)
		self.set_has_separator(False)
		#self.set_decorated(False)
		#self.skip_taskbar_hint = True
		
		icon = gtk.Image()
		icon.set_from_stock(stock_icon_id,gtk.ICON_SIZE_DIALOG)
		icon.set_alignment(0,0)
		hbox = gtk.HBox(spacing=12)
		hbox.set_border_width(6)
		hbox.pack_start(icon)
		vbox = gtk.VBox(spacing=12)
		primary_label = TitleLabel(primary_text)
		vbox.pack_start(primary_label)
		if secondary_text:
			secondary_label = LeftAlignedLabel(secondary_text)
			vbox.pack_start(secondary_label)
		hbox.pack_start(vbox)
		self.vbox.pack_start(hbox)
		self.vbox.set_spacing(12)
		self.vbox.show_all()
		self.action_area.get_children()[0].grab_default()
		
	def run(self):
		retvalue = gtk.Dialog.run(self)
		self.destroy()
		return retvalue

class InformationAlert(Alert):
	
	def __init__(self,parent_window,primary_text, secondary_text=None,extra_buttons=None,flags=0):
		Alert.__init__(self,parent_window,primary_text,secondary_text,((gtk.STOCK_OK,gtk.RESPONSE_OK),),flags,stock_icon_id=gtk.STOCK_DIALOG_INFO)
		if extra_buttons:
			for idortext,responseid in extra_buttons:
				b = self.add_button(idortext,responseid)
				self.action_area.reorder_child(b,0)
		self.action_area.get_children()[0].grab_focus()


class ErrorAlert(Alert):
	
	def __init__(self,parent_window,primary_text, secondary_text=None,extra_buttons=None,flags=0):
		Alert.__init__(self,parent_window,primary_text,secondary_text,((gtk.STOCK_OK,gtk.RESPONSE_OK),),flags,stock_icon_id=gtk.STOCK_DIALOG_ERROR)
		if extra_buttons:
			for idortext,responseid in extra_buttons:
				b = self.add_button(idortext,responseid)
				self.action_area.reorder_child(b,0)
		self.action_area.get_children()[0].grab_focus()

class ConfirmationAlert(Alert):
	
	def __init__(self,parent_window,primary_text, secondary_text=None,confirm_button=None,alternate_button=None,flags=0):
		if confirm_button is None: confirm_button = (gtk.STOCK_OK,gtk.RESPONSE_OK)
		cancel_button = (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL)
		buttons = (cancel_button,confirm_button)
		Alert.__init__(self,parent_window,primary_text,secondary_text,buttons,stock_icon_id=gtk.STOCK_DIALOG_WARNING)
		if alternate_button:
			b = self.add_button(*alternate_button)
			self.action_area.reorder_child(b,0)
		self.action_area.get_children()[0].grab_focus()

class SaveConfirmationAlert(ConfirmationAlert):
	def __init__(self,parent_window,primary_text, secondary_text=None,flags=0):
		ConfirmationAlert.__init__(self,parent_window,primary_text,secondary_text,confirm_button=("Save",gtk.RESPONSE_YES),alternate_button=("Close without saving",gtk.RESPONSE_NO),flags=flags)


def test():
	a = gtk.Window()
	extra_buttons = ((gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL),(gtk.STOCK_CLOSE,gtk.RESPONSE_CLOSE),)
	alternate_button = (gtk.STOCK_CLOSE,gtk.RESPONSE_CLOSE)
	d = ConfirmationAlert(a,"Remove file nisecuanto?","Removing file nisecuanto may cause problems with essential operating system functions, but you will win extra disk space",alternate_button=alternate_button,flags=0)
	a.show()
	
	def p(d):
		print d.run()
		d.destroy()
		gtk.main_quit()
		
	gobject.idle_add(p,d)
	gtk.main()
	
	
if __name__ == "__main__":
	test()